!-----------------------------------------------------------------
!--------------- special set of characters for RCS information
!-----------------------------------------------------------------
! $Source$ $Revision$ $Date$
!-----------------------------------------------------------------
!-----------------------------------------------------------------
!-----------------------------------------------------------------
!###########################
MODULE MODI_INIT_FOR_CONVLFI
!###########################
!
INTERFACE
      SUBROUTINE INIT_FOR_CONVLFI(HINIFILE,HLUOUT)
!
CHARACTER(LEN=28),      INTENT(IN)    :: HINIFILE    ! file being read
CHARACTER(LEN=*),       INTENT(IN)    :: HLUOUT      ! output listing
!
END SUBROUTINE INIT_FOR_CONVLFI
END INTERFACE
END MODULE MODI_INIT_FOR_CONVLFI
!
!     ############################################
      SUBROUTINE INIT_FOR_CONVLFI(HINIFILE,HLUOUT)
!     ############################################
!
!!****  *INIT_FOR_CONVLFI * - light monitor to initialize the variables 
!!
!!    PURPOSE
!!    -------
!       The purpose of this routine is to initialize some variables   
!     necessary in the conversion program.
!
!!**  METHOD
!!    ------
!!      This initialization takes some parts of the whole initialization modules
!!    of monitor INIT: 
!!        geometry and dimensions from ini_sizen
!!        grids, metric coefficients, dates and times from set_grid
!!        reading of the pressure field
!!             
!!
!!    EXTERNAL
!!    --------
!!      INI_CST    : to initialize physical constants
!!
!!
!!    IMPLICIT ARGUMENTS
!!    ------------------ 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	I. Mallet       * Meteo France *
!!
!!    MODIFICATIONS
!!    -------------
!!      Original    20/02/01 
!-------------------------------------------------------------------------------
!
!*       0.    DECLARATIONS
!              ------------
!
USE MODD_PARAMETERS
USE MODD_CONF
USE MODD_CST
USE MODD_DIM1
USE MODD_FIELD1
USE MODD_GRID
USE MODD_GRID1
USE MODD_TIME
USE MODD_TIME1
!USE MODD_VAR_ll, ONLY : NPROC
!
USE MODE_TIME
USE MODE_GRIDPROJ
USE MODE_GRIDCART
!
!USE MODE_FM
!USE MODE_FMREAD
USE MODI_FMREAD
!USE MODE_IO_ll
!USE MODE_ll
!
!USE MODI_GATHER_ll 
USE MODI_INI_CST
!
IMPLICIT NONE
!
!*       0.1   Arguments variables
!
CHARACTER(LEN=28),      INTENT(IN)    :: HINIFILE    ! file being read
CHARACTER(LEN=*),       INTENT(IN)    :: HLUOUT      ! output listing
!
!*       0.2   Local variables
!
INTEGER  :: IGRID,ILENCH,IRESP,ILUOUT          ! return code of file management
CHARACTER (LEN=16)     :: YRECFM               ! management
CHARACTER (LEN=100)    :: YCOMMENT             ! variables
CHARACTER (LEN=2)      :: YDIR   
INTEGER, DIMENSION(3)  :: ITDATE               ! date array
CHARACTER (LEN=40)     :: YTITLE               ! Title for date print
REAL, DIMENSION(:,:,:), ALLOCATABLE :: ZJ      ! Jacobian
!
REAL                :: ZXHATM,ZYHATM    ! coordinates of mass point 
REAL                :: ZLATORI, ZLONORI ! lat and lon of left-bottom point
INTEGER             :: IIU,IJU       ! Upper dimension in x,y direction (local)
INTEGER             :: IKU           ! Upper dimension in z direction
INTEGER             :: IINFO_ll      ! return code of // routines
INTEGER             :: ILENG     ! for old fmread
INTEGER                :: IMASDEV                   ! masdev of the file
LOGICAL                :: GSLEVE    ! local flag for SLEVE coordinate
!-------------------------------------------------------------------------------
!
!CALL FMLOOK_ll(HLUOUT,HLUOUT,ILUOUT,IRESP)
CALL FMLOOK(HLUOUT,HLUOUT,ILUOUT,IRESP)
!
!*       1.    INITIALIZE EACH MODEL SIZES AND DEPENDENCY (ini_sizen)
!              ------------------------------------------
!
!*       1.1   Read the geometry kind in the LFIFM file (Cartesian or spherical)
!
YRECFM = 'CARTESIAN'
YDIR='--'
ILENG=1
!CALL FMREAD(HINIFILE,YRECFM,HLUOUT,YDIR,LCARTESIAN,IGRID,ILENCH,YCOMMENT,IRESP)
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,LCARTESIAN,IGRID,ILENCH,YCOMMENT,IRESP)
!
!*       1.2  Read dimensions in initial file and initialize  subdomain 
!             dimensions and parallel variables
!
YRECFM='IMAX'
YDIR='--'
ILENG=1
!CALL FMREAD(HINIFILE,YRECFM,HLUOUT,YDIR,NIMAX_ll,IGRID,ILENCH,YCOMMENT,IRESP)
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,NIMAX,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='JMAX'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,NJMAX,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM = 'L1D'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,L1D,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP/=0) THEN
  L1D=.FALSE.
  IF( (NIMAX == 1).AND.(NJMAX == 1) ) L1D=.TRUE.
ENDIF  
!
YRECFM = 'L2D'
YDIR='--'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,L2D,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP/=0) THEN
  L2D=.FALSE.
  IF( (NIMAX /= 1).AND.(NJMAX == 1) ) L2D=.TRUE.
ENDIF  
!
YRECFM = 'PACK'
YDIR='--'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,LPACK,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP/=0) LPACK=.FALSE.
!
YRECFM='KMAX'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,NKMAX,IGRID,ILENCH,YCOMMENT,IRESP)
!
!CSPLIT ='YSPLITTING' ; NHALO = 1
!CALL SET_SPLITTING_ll(CSPLIT)
!CALL SET_JP_ll(1,JPHEXT,JPVEXT, NHALO)
!CALL SET_DAD0_ll()
!CALL SET_DIM_ll(NIMAX_ll, NJMAX_ll, NKMAX)
!CALL SET_FMPACK_ll(L1D,L2D,LPACK)
!CALL SET_LBX_ll('OPEN', 1)
!CALL SET_LBY_ll('OPEN', 1)
!CALL SET_XRATIO_ll(1, 1)
!CALL SET_YRATIO_ll(1, 1)
!CALL SET_XOR_ll(1, 1)
!CALL SET_XEND_ll(NIMAX_ll+2*JPHEXT, 1)
!CALL SET_YOR_ll(1, 1)
!CALL SET_YEND_ll(NJMAX_ll+2*JPHEXT, 1)
!CALL SET_DAD_ll(0, 1)
!CALL INI_PARA_ll(IINFO_ll)
!
!*       1.3  Compute sizes of arrays of the extended sub-domain (ini_modeln)
!
IKU=NKMAX + 2*JPVEXT
!CALL GET_DIM_EXT_ll('B',IIU,IJU)
!CALL GET_DIM_PHYS_ll('B',NIMAX,NJMAX)
IIU=NIMAX +2*JPHEXT
IJU=NJMAX +2*JPHEXT
!
!-------------------------------------------------------------------------------
!
!*       2.    INITIALIZE GRIDS AND METRIC COEFFICIENTS (set_grid)
!              ---------------------
!
!        2.1  reading
!
YRECFM='LON0'   
YDIR='--'   
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLON0,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='LAT0'
YDIR='--'     
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLAT0,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='BETA'  
YDIR='--'       
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XBETA,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='XHAT'
ALLOCATE(XXHAT(IIU))
YDIR='XX'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,IIU,XXHAT,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='YHAT'
ALLOCATE(XYHAT(IJU))
YDIR='YY'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,IJU,XYHAT,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='MASDEV' 
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,IMASDEV,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP /=0) IMASDEV=43
!
IF (.NOT.LCARTESIAN) THEN
  YRECFM='RPK'
  YDIR='--'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XRPK,IGRID,ILENCH,YCOMMENT,IRESP)
  !
  YRECFM='LONORI'
  YDIR='--'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLONORI,IGRID,ILENCH,YCOMMENT,IRESP)
  !
  YRECFM='LATORI'
  YDIR='--'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLATORI,IGRID,ILENCH,YCOMMENT,IRESP)
  !
  IF (IMASDEV<=45) THEN
    CALL FMREAD(HINIFILE,'LONOR',HLUOUT,ILENG,XLONORI,IGRID,ILENCH,YCOMMENT,IRESP)
    CALL FMREAD(HINIFILE,'LATOR',HLUOUT,ILENG,XLATORI,IGRID,ILENCH,YCOMMENT,IRESP)
    !ALLOCATE(ZXHAT_ll(NIMAX_ll+ 2 * JPHEXT),ZYHAT_ll(NJMAX_ll+2 * JPHEXT))
    !CALL GATHERALL_FIELD_ll('XX',XXHAT,ZXHAT_ll,IRESP) !//
    !CALL GATHERALL_FIELD_ll('YY',XYHAT,ZYHAT_ll,IRESP) !//
    ZXHATM = - 0.5 * (XXHAT(1)+XXHAT(2))
    ZYHATM = - 0.5 * (XYHAT(1)+XYHAT(2))
    CALL SM_LATLON(XLATORI,XLONORI,ZXHATM,ZYHATM,ZLATORI,ZLONORI)
    !DEALLOCATE(ZXHAT_ll,ZYHAT_ll)
    XLATORI = ZLATORI
    XLONORI = ZLONORI
  END IF
END IF
!
!
YRECFM='ZS'
ALLOCATE(XZS(IIU,IJU))
YDIR='XY'
ILENG=IIU*IJU
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XZS,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP/=0) XZS(:,:)=0.
!
YRECFM='ZHAT'
ALLOCATE(XZHAT(IKU))
YDIR='--'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,IKU,XZHAT,IGRID,ILENCH,YCOMMENT,IRESP)
!
LSLEVE=.FALSE.
XLEN1=7500.
XLEN2=2500.
ALLOCATE(XZSMT(IIU,IJU))
!
IF (IMASDEV<=46) THEN
  XZSMT  = XZS
  LSLEVE = .FALSE.
ELSE
  YRECFM='SLEVE'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,GSLEVE,IGRID,ILENCH,YCOMMENT,IRESP)
  IF (IRESP ==0) LSLEVE=GSLEVE
  !
  YRECFM='ZSMT'
  ILENG=IIU*IJU
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XZSMT,IGRID,ILENCH,YCOMMENT,IRESP)
  !
  YRECFM='LEN1'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLEN1,IGRID,ILENCH,YCOMMENT,IRESP)
  !
  YRECFM='LEN2'
  ILENG=1
  CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XLEN2,IGRID,ILENCH,YCOMMENT,IRESP)
  print *,'init_for_convlfi: SLEVE=',LSLEVE,XLEN1,XLEN2
END IF
!
YRECFM='DTEXP%TDATE' 
YDIR='--'
ILENG=3
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,ITDATE,IGRID,ILENCH,YCOMMENT,IRESP)
TDTEXP%TDATE=DATE(ITDATE(1),ITDATE(2),ITDATE(3))  
!
YRECFM='DTEXP%TIME'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,TDTEXP%TIME,IGRID,ILENCH,YCOMMENT,IRESP)
!   
YRECFM='DTMOD%TDATE' 
YDIR='--'
ILENG=3
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,ITDATE,IGRID,ILENCH,YCOMMENT,IRESP)
TDTMOD%TDATE=DATE(ITDATE(1),ITDATE(2),ITDATE(3)) 
!
YRECFM='DTMOD%TIME'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,TDTMOD%TIME,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='DTSEG%TDATE' 
YDIR='--'
ILENG=3
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,ITDATE,IGRID,ILENCH,YCOMMENT,IRESP)
TDTSEG%TDATE=DATE(ITDATE(1),ITDATE(2),ITDATE(3)) 
!
YRECFM='DTSEG%TIME'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,TDTSEG%TIME,IGRID,ILENCH,YCOMMENT,IRESP)
!
YRECFM='DTCUR%TDATE' 
YDIR='--'
ILENG=3
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,ITDATE,IGRID,ILENCH,YCOMMENT,IRESP)
TDTCUR%TDATE=DATE(ITDATE(1),ITDATE(2),ITDATE(3)) 
!
YRECFM='DTCUR%TIME'
YDIR='--'
ILENG=1
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,TDTCUR%TIME,IGRID,ILENCH,YCOMMENT,IRESP)
!
YTITLE='CURRENT DATE AND TIME'
CALL SM_PRINT_TIME(TDTCUR,HLUOUT,YTITLE)
!
!*       3.2    Spatial grid
! 
ALLOCATE(XDXHAT(IIU))
ALLOCATE(XDYHAT(IJU))
ALLOCATE(XZZ(IIU,IJU,IKU))
ALLOCATE(ZJ(IIU,IJU,IKU))
!
YRECFM='STORAGE_TYPE'
YDIR='--'   
ILENG=2
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,CSTORAGE_TYPE,IGRID,ILENCH,YCOMMENT,IRESP)
IF (IRESP/=0) CSTORAGE_TYPE='MT'
IF (CSTORAGE_TYPE=='PG') CCONF='POSTP'   ! pour fichier PGD dans mode_gridproj
!
CALL INI_CST
!
IF (LCARTESIAN) THEN
  CALL SM_GRIDCART(HLUOUT,XXHAT,XYHAT,XZHAT,XZS,LSLEVE,XLEN1,XLEN2,XZSMT,XDXHAT,XDYHAT,XZZ,ZJ) 
ELSE
  ALLOCATE(XLON(IIU,IJU))
  ALLOCATE(XLAT(IIU,IJU))
  ALLOCATE(XMAP(IIU,IJU))
  CALL SM_GRIDPROJ(HLUOUT,XXHAT,XYHAT,XZHAT,XZS,LSLEVE,XLEN1,XLEN2,XZSMT,XLATORI,XLONORI, &
                   XMAP,XLAT,XLON,XDXHAT,XDYHAT,XZZ,ZJ)  
END IF    
!
!-------------------------------------------------------------------------------
!
!*       4.    INITIALIZE THE PROGNOSTIC AND SURFACE FIELDS (read_field)
!              --------------------------------------------
ALLOCATE(XPABSM(IIU,IJU,IKU))
ALLOCATE(XPABST(IIU,IJU,IKU))
!
YDIR='XY'
ILENG=IIU*IJU*IKU
YRECFM = 'PABSM'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XPABSM,IGRID,ILENCH,YCOMMENT,IRESP)
YRECFM = 'PABST'
CALL FMREAD(HINIFILE,YRECFM,HLUOUT,ILENG,XPABST,IGRID,ILENCH,YCOMMENT,IRESP)
!
!-------------------------------------------------------------------------------
!
END SUBROUTINE INIT_FOR_CONVLFI
